@@ -530,7 +530,7 @@ def main(args, test=False):
     SpAItag, SpAI_idx, is_SpAI = '', 0, False
     ENSG_idx, ENST_idx, IMPCT_idx = 0, 0, 0
     SpliceAItag = args['SpliceAItag'] if args['SpliceAItag'] else 'SpliceAI'
-    VEPtag = args['VEPtag'] if args['VEPtag'] else 'VEP'
+    VEPtag = args['VEPtag'] if args['VEPtag'] else 'CSQ'
     sep = args['sep'] if args['sep'] else '&'
     allow_undef = True if args['allow_undef'] else False
     filter_cmpHet = True if args['filter_cmpHet'] else False
